==> seedsui-react-3.0.4.tgz: package/es/Player/Player.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import PlayerDialog from './PlayerDialog';

var Player = (_temp = _class = function (_Component) {
  _inherits(Player, _Component);

  // 全局配置
  function Player(props) {
    _classCallCheck(this, Player);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.state = {
      videoShow: false
    };

    _this.play = function (e, show) {
      _this.setState({
        videoShow: show
      });
      e.stopPropagation();
    };

    return _this;
  }

  Player.prototype.componentDidMount = function componentDidMount() {
    this.$ComponentPlayerDialog = this.refs.$ComponentPlayerDialog;
    this.$video = this.refs.$ComponentPlayerDialog.$el;
  };
  // 显隐视频弹窗


  Player.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        portal = _props.portal,
        src = _props.src,
        _props$maskAttribute = _props.maskAttribute,
        maskAttribute = _props$maskAttribute === undefined ? {} : _props$maskAttribute,
        _props$videoAttribute = _props.videoAttribute,
        videoAttribute = _props$videoAttribute === undefined ? {} : _props$videoAttribute,
        poster = _props.poster,
        children = _props.children,
        others = _objectWithoutProperties(_props, ['portal', 'src', 'maskAttribute', 'videoAttribute', 'poster', 'children']);

    return React.createElement(
      'div',
      _extends({ ref: function ref(el) {
          _this2.$el = el;
        } }, others, { className: 'player-thumbnail' + (others.className ? ' ' + others.className : ''), onClick: others.onClick ? others.onClick : function (e) {
          return _this2.play(e, true);
        } }),
      poster && React.createElement('div', { style: { backgroundImage: 'url(' + poster + ')' }, className: 'player-thumbnail-poster' }),
      React.createElement('div', { className: 'player-thumbnail-button' }),
      children,
      React.createElement(PlayerDialog, {
        ref: '$ComponentPlayerDialog',
        show: this.state.videoShow,
        portal: portal,
        src: src,
        maskAttribute: maskAttribute,
        videoAttribute: videoAttribute,
        onHide: function onHide(e) {
          return _this2.play(e, false);
        }
      })
    );
  };

  return Player;
}(Component), _class.contextTypes = {
  locale: PropTypes.object,
  portal: PropTypes.object
}, _class.defaultProps = {}, _temp);
export { Player as default };
Player.propTypes = process.env.NODE_ENV !== "production" ? {
  portal: PropTypes.object,
  src: PropTypes.string,
  maskAttribute: PropTypes.object,
  videoAttribute: PropTypes.object,
  poster: PropTypes.string,
  children: PropTypes.node
} : {};

==> seedsui-react-3.7.9.tgz: package/es/Player/Player.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import PlayerDialog from './PlayerDialog';
import Context from '../Context/instance.js';

var Player = (_temp = _class = function (_Component) {
  _inherits(Player, _Component);

  function Player(props) {
    _classCallCheck(this, Player);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.state = {
      videoShow: false
    };

    _this.play = function (e, show) {
      _this.setState({
        videoShow: show
      });
      e.stopPropagation();
    };

    return _this;
  }

  Player.prototype.componentDidMount = function componentDidMount() {
    this.$ComponentPlayerDialog = this.refs.$ComponentPlayerDialog;
    this.$video = this.refs.$ComponentPlayerDialog.$el;
  };
  // 显隐视频弹窗


  Player.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        portal = _props.portal,
        src = _props.src,
        _props$maskAttribute = _props.maskAttribute,
        maskAttribute = _props$maskAttribute === undefined ? {} : _props$maskAttribute,
        _props$videoAttribute = _props.videoAttribute,
        videoAttribute = _props$videoAttribute === undefined ? {} : _props$videoAttribute,
        poster = _props.poster,
        children = _props.children,
        others = _objectWithoutProperties(_props, ['portal', 'src', 'maskAttribute', 'videoAttribute', 'poster', 'children']);

    return React.createElement(
      'div',
      _extends({ ref: function ref(el) {
          _this2.$el = el;
        } }, others, { className: 'player-thumbnail' + (others.className ? ' ' + others.className : ''), onClick: others.onClick ? others.onClick : function (e) {
          return _this2.play(e, true);
        } }),
      poster && React.createElement('div', { style: { backgroundImage: 'url(' + poster + ')' }, className: 'player-thumbnail-poster' }),
      React.createElement('div', { className: 'player-thumbnail-button' }),
      children,
      React.createElement(PlayerDialog, {
        ref: '$ComponentPlayerDialog',
        show: this.state.videoShow,
        portal: portal,
        src: src,
        maskAttribute: maskAttribute,
        videoAttribute: videoAttribute,
        onHide: function onHide(e) {
          return _this2.play(e, false);
        }
      })
    );
  };

  return Player;
}(Component), _class.contextType = Context, _class.defaultProps = {}, _temp);
export { Player as default };
Player.propTypes = process.env.NODE_ENV !== "production" ? {
  portal: PropTypes.object,
  src: PropTypes.string,
  maskAttribute: PropTypes.object,
  videoAttribute: PropTypes.object,
  poster: PropTypes.string,
  children: PropTypes.node
} : {};
